==> koha-3.14.10.tar.gz: koha-3.14.10/installer/data/mysql/de-DE/mandatory/userflags.sql <==
INSERT INTO `userflags` VALUES(0,'superlibrarian','Zugriff auf alle Funktionen',0);
INSERT INTO `userflags` VALUES(1,'circulate','Medien ausleihen/zurückgeben',0);
INSERT INTO `userflags` VALUES(2,'catalogue','Katalogsuche verwenden (Dienstoberfläche)',0);
INSERT INTO `userflags` VALUES(3,'parameters','Systemparameter verändern',0);
INSERT INTO `userflags` VALUES(4,'borrowers','Benutzer anlegen/ändern',0);
INSERT INTO `userflags` VALUES(5,'permissions','Berechtigungen für Benutzer vergeben',0);
INSERT INTO `userflags` VALUES(6,'reserveforothers','Vormerkungen für Benutzer setzen/ändern',0);
INSERT INTO `userflags` VALUES(7,'borrow','Medien entleihen',1);
INSERT INTO `userflags` VALUES(9,'editcatalogue','Katalogdaten ändern (Titel- und Bestandsdaten ändern)',0);
INSERT INTO `userflags` VALUES(10,'updatecharges','Gebühren kassieren/ändern',0);
INSERT INTO `userflags` VALUES(11,'acquisition','Erwerbung und Verwaltung von Anschaffungsvorschlägen',0);
INSERT INTO `userflags` VALUES(12,'management','Zugriff auf Administration',0);
INSERT INTO `userflags` VALUES(13,'tools','Werkzeuge verwenden (Export, Import, Etikettendruck)',0);
INSERT INTO `userflags` VALUES(14,'editauthorities','Normdaten ändern',0);
INSERT INTO `userflags` VALUES(15,'serials','Zugriff auf Abonnementverwaltung/Zeitschriftenmodul',0);
INSERT INTO `userflags` VALUES(16,'reports','Zugriff auf Reportmodul',0);
INSERT INTO `userflags` VALUES(17,'staffaccess','Berechtigungen/Logins für Bibliotheksmitarbeiter vergeben',0);
INSERT INTO `userflags` VALUES(18,'coursereserves','Semesteraparate',0);
INSERT INTO `userflags` VALUES(19,'plugins', 'Koha Plugins', '0');

==> koha-3.16.06.tar.gz: koha-3.16.06/installer/data/mysql/de-DE/mandatory/userflags.sql <==
INSERT INTO `userflags` VALUES(0,'superlibrarian','Zugriff auf alle Funktionen',0);
INSERT INTO `userflags` VALUES(1,'circulate','Medien ausleihen/zurückgeben',0);
INSERT INTO `userflags` VALUES(2,'catalogue','Katalogsuche verwenden (Dienstoberfläche)',0);
INSERT INTO `userflags` VALUES(3,'parameters','Administration und Systemparameter',0);
INSERT INTO `userflags` VALUES(4,'borrowers','Benutzer anlegen/ändern',0);
INSERT INTO `userflags` VALUES(5,'permissions','Berechtigungen für Benutzer vergeben',0);
INSERT INTO `userflags` VALUES(6,'reserveforothers','Vormerkungen für Benutzer setzen/ändern',0);
INSERT INTO `userflags` VALUES(7,'borrow','Medien entleihen',1);
INSERT INTO `userflags` VALUES(9,'editcatalogue','Katalogdaten ändern (Titel- und Bestandsdaten ändern)',0);
INSERT INTO `userflags` VALUES(10,'updatecharges','Gebühren verwalten',0);
INSERT INTO `userflags` VALUES(11,'acquisition','Erwerbung und Verwaltung von Anschaffungsvorschlägen',0);
INSERT INTO `userflags` VALUES(12,'management','Zugriff auf Administration',0);
INSERT INTO `userflags` VALUES(13,'tools','Werkzeuge verwenden (Export, Import, Etikettendruck)',0);
INSERT INTO `userflags` VALUES(14,'editauthorities','Normdaten verwalten',0);
INSERT INTO `userflags` VALUES(15,'serials','Zugriff auf Abonnementverwaltung/Zeitschriftenmodul',0);
INSERT INTO `userflags` VALUES(16,'reports','Zugriff auf Reports',0);
INSERT INTO `userflags` VALUES(17,'staffaccess','Berechtigungen/Logins für Bibliotheksmitarbeiter vergeben',0);
INSERT INTO `userflags` VALUES(18,'coursereserves','Semesterapparate',0);
INSERT INTO `userflags` VALUES(19,'plugins', 'Koha Plugins', '0');
